==> odoo_17.0.20251229.zip: odoo-17.0.post20251229/odoo/addons/sale/static/src/js/sale_progressbar_field.js <==
/** @odoo-module **/

import { registry } from "@web/core/registry";
import { useService } from "@web/core/utils/hooks";
import {
    KanbanProgressBarField,
    kanbanProgressBarField,
} from "@web/views/fields/progress_bar/kanban_progress_bar_field";
import { useEffect } from "@odoo/owl";

/**
 * A custom Component for the view of sales teams on the kanban view in the CRM app.
 *
 * The wanted behavior is to show a progress bar when an invoicing target is defined or show
 * a link redirecting to the record's form view otherwise.
 */
export class SaleProgressBarField extends KanbanProgressBarField {
    /**
     * Anything used by the component is defined on the setup method.
     */
    setup() {
        super.setup();

        this.actionService = useService("action");
        this.orm = useService("orm");

        useEffect(() => {
            this.state.isInvoicingTargetDefined = this.props.record.data[this.props.maxValueField];
        });
    }

    /**
     * Display the form view of the record on click.
     */
    async defineInvoicingTarget() {
        const { resId, resModel } = this.props.record;
        const action = await this.orm.call(resModel, "get_formview_action", [[resId]]);
        this.actionService.doAction(action, { props: { mode: "edit" } });
    }
}

/**
 * Define the template name used on the component.
 */
SaleProgressBarField.template = "sale.SaleProgressBarField";

export const saleProgressBarField = {
    ...kanbanProgressBarField,
    component: SaleProgressBarField,
};

registry.category("fields").add("sales_team_progressbar", saleProgressBarField);

==> odoo_19.3a1.20260226.zip: odoo-19.3a1.post20260226/odoo/addons/sale/static/src/js/sale_progressbar_field.js <==
import { useLayoutEffect } from "@web/owl2/utils";
import { registry } from "@web/core/registry";
import { useService } from "@web/core/utils/hooks";
import {
    KanbanProgressBarField,
    kanbanProgressBarField,
} from "@web/views/fields/progress_bar/kanban_progress_bar_field";

/**
 * A custom Component for the view of sales teams on the kanban view in the CRM app.
 *
 * The wanted behavior is to show a progress bar when an invoicing target is defined or show
 * a link redirecting to the record's form view otherwise.
 */
export class SaleProgressBarField extends KanbanProgressBarField {
    static template = "sale.SaleProgressBarField";
    /**
     * Anything used by the component is defined on the setup method.
     */
    setup() {
        super.setup();

        this.actionService = useService("action");
        this.orm = useService("orm");

        useLayoutEffect(() => {
            this.state.isInvoicingTargetDefined = this.props.record.data[this.props.maxValueField];
        });
    }

    /**
     * Display the form view of the record on click.
     */
    async defineInvoicingTarget() {
        const { resId, resModel } = this.props.record;
        const action = await this.orm.call(resModel, "get_formview_action", [[resId]]);
        this.actionService.doAction(action);
    }
}

export const saleProgressBarField = {
    ...kanbanProgressBarField,
    component: SaleProgressBarField,
};

registry.category("fields").add("sales_team_progressbar", saleProgressBarField);
